@@ -149,6 +149,7 @@ def _retry_request(http, num_retries, req_type, sleep, rand, uri, method, *args,
   """
   resp = None
   content = None
+  exception = None
   for retry_num in range(num_retries + 1):
     if retry_num > 0:
       # Sleep before retrying.
@@ -558,9 +559,13 @@ class MediaFileUpload(MediaIoBaseUpload):
       if mimetype is None:
         # Guess failed, use octet-stream.
         mimetype = 'application/octet-stream'
-    super(MediaFileUpload, self).__init__(fd, mimetype, chunksize=chunksize,
+    super(MediaFileUpload, self).__init__(fd, mimetype,
+                                          chunksize=chunksize,
                                           resumable=resumable)
 
+  def __del__(self):
+    self._fd.close()
+
   def to_json(self):
     """Creating a JSON representation of an instance of MediaFileUpload.
 
